@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_compose.c,v 1.3 2008/05/23 12:18:33 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_compose.c,v 1.5 2008/09/17 17:20:25 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -58,7 +58,6 @@ static BOOL cmd_compose_generate_postponed_list(struct session *session)
 {
     struct template_vals *tvals = session->template_vals;
     struct config *config = session->config;
-    struct prefs *prefs = session->options->prefs;
     struct request *request = session->request;
     struct buffer *b = request->write_buffer;
     MAILSTREAM *stream = session->draft_stream;
@@ -82,13 +81,8 @@ static BOOL cmd_compose_generate_postponed_list(struct session *session)
         template_vals_foreach_ulong(tvals, "@list", count, "msgno", msgno);
         
         /* Message Date */
-        if (prefs->use_full_date)
-            string = string_date_to_string_long(elt->month, elt->day,
-                                                elt->year + BASEYEAR);
-        else
-            string = string_date_to_string_short(elt->month, elt->day);
-
-        template_vals_foreach_string(tvals, "@list", count, "date", string);
+        template_vals_foreach_string(tvals, "@list", count, "date",
+                                     mc_date_to_string(elt));
 
         /* To/Cc/Bcc address (use first non-empty address) */
         if (!((addr = env->to) && addr->mailbox && addr->host))
@@ -421,7 +415,7 @@ void cmd_compose(struct session *session)
                              session->compose_parent_cmd);
             return;
         } else {
-            session_message(session, "Failed to write postponed message");
+            session_alert(session, "Failed to write postponed message");
             session_log(session,
                         "[cmd_compose] Failed to write postponed message: %s",
                         ml_errmsg());
@@ -470,7 +464,7 @@ void cmd_compose(struct session *session)
                              pool_strcat(request->pool, "change/", name));
             return;
         } else
-            session_message(session, "Invalid mail folder");
+            session_alert(session, "Invalid mail folder");
     }
 
     if (assoc_lookup(h, "sub_help")) {
