@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/servers/session_exchange.c,v 1.3 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/servers/session_exchange.c,v 1.6 2010/07/02 15:02:32 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -58,74 +58,6 @@ BOOL session_exchange(struct session * session)
     } else
         request->allow_gzip = NIL;
 
-    /* Cope with "/robots.txt" */
-    if ((request->argc == 1)
-        && (!strcasecmp(request->argv[0], "robots.txt"))) {
-        struct buffer *b = request->write_buffer;
-
-        bputs(b, "User-agent: *" CRLF);
-        bputs(b, "Disallow: /session" CRLF);
-        bputs(b, "Disallow: /login" CRLF);
-        bputs(b, "Disallow: /icons" CRLF);
-        response_text(request, 200);
-        return (NIL);
-    }
-
-    if (request->argc < 3) {
-        response_error(request, 404);
-        return (NIL);
-    }
-
-    /* Replace empty argv[2] with "CRSid=session" value if cookie exists */
-    if (request->argv[2][0] == '\0') {
-        char *s = assoc_lookup(request->hdrs, "cookie");
-        char *t;
-        char *u;
-        char *key;
-
-        if (config->http_cookie_use_port)
-            key = pool_printf(request->pool, "%s:%lu",
-                              request->argv[1], session->session_port);
-        else
-            key = request->argv[1];
-
-
-        /* Need cookie parsing library? */
-        while (s && *s && (t = strchr(s, '='))) {
-            *t++ = '\0';
-            if ((u = strchr(t, ';')))
-                *u++ = '\0';
-
-            if (!strcmp(string_trim_whitespace(s), key)) {
-                request->argv[2] = string_trim_whitespace(t);
-                break;
-            }
-            s = u;
-        }
-    }
-
-    /* Decode username argument */
-    string_url_decode(request->argv[1]);
-
-    /* Check that username and sessionID correspond to this session... */
-    if ((strcmp(request->argv[1], session->username) != 0) ||
-        (strcmp(request->argv[2], session->sessionid) != 0)) {
-        struct buffer *b = request->write_buffer;
-
-        html_common_start(config, b, "Session disconnected");
-        bputs(b, "<h3>" CRLF);
-        bputs(b, "Couldn't connect to session. Maybe it timed out?" CRLF);
-        bprintf(b,
-                "<p>Click <a href=\"%s/login/%s\">here</a> to login again</p>"
-                CRLF, session->url_prefix, request->argv[1]);
-        bputs(b, "</h3>" CRLF);
-        html_common_end(b);
-
-        /* Do we need to kill session cookie? Next login should kill anyway */
-        response_html(request, 404);
-        return (NIL);
-    }
-
     /* argv: /session/username/session/sequence... */
 
     if ((request->argc < 5) || (strcmp(request->argv[0], "session") != 0)) {
