@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/account_sieve.c,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/account_sieve.c,v 1.6 2010/07/05 16:04:24 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -453,7 +453,19 @@ account_sieve_text(struct account *account, struct pool *pool)
     if (account->vacation_enabled) {
         bputs(b, "vacation"CRLF);
         bprintf(b, "  :days %d"CRLF, account->vacation_days);
-        bputs(b, "  :subject \"Auto-Response: Vacation Message\""CRLF);
+        if (account->vacation_subject && account->vacation_subject[0]) {
+            char *s = account->vacation_subject;
+            char c;
+
+            bputs(b, "  :subject \"");
+            while ((c=*s++)) {
+                if (c == '\"')
+                    bputc(b, '\\');
+                bputc(b, c);
+            }
+            bputs(b, "\""CRLF);
+        } else
+            bputs(b, "  :subject \"Auto-Response: Vacation Message\""CRLF);
 
         if (account->vacation_aliases && account->vacation_aliases[0]) {
             bputs(b, "  :addresses ["CRLF);
@@ -562,14 +574,27 @@ account_sieve_mail_check(struct account * account, struct pool * pool)
     char *auto_text;
     char *key = "";
     char *value = "";
-    char *sieve_text;
+    char *sieve_text = "";
     char *vacation_msg = "";
     char *vacation_aliases = "";
+    char *vacation_subject = "";
     char *spam_whitelist = "";
     char *filters = "";
 
     account->sieve_have_auto  = NIL;
     
+    if (!sieve_fetch(sieve, session, "sieve", &sieve_text)) {
+        account_message(account, "Failed to download active sieve file");
+        return(NIL);
+    }
+    sieve_current_record(sieve, sieve_text);
+    sieve_live_record(sieve, sieve_text);
+
+    if (sieve_text && sieve_text[0] && !checksum_test(sieve_text, pool)) {
+        account_message(account, "Manually maintained Sieve file");
+        return(NIL);
+    }
+
     if (!sieve_fetch(sieve, session, "auto", &auto_text)) {
         account_message(account, "Failed to check mail redirection status");
         return(NIL);
@@ -596,6 +621,8 @@ account_sieve_mail_check(struct account * account, struct pool * pool)
 
         if (!strcmp(key, "vacation_aliases:"))
             vacation_aliases = value;
+        else if (!strcmp(key, "vacation_subject:"))
+            vacation_subject = value;
         else if (!strcmp(key, "vacation_msg:"))
             vacation_msg = value;
         else if (!strcmp(key, "spam_whitelist:"))
@@ -607,20 +634,9 @@ account_sieve_mail_check(struct account * account, struct pool * pool)
     /* Fold vacation aliases into single line */
     vacation_aliases = account_sieve_combine_lines(vacation_aliases, pool);
 
-    if (!sieve_fetch(sieve, session, "sieve", &sieve_text)) {
-        account_message(account, "Failed to download active sieve file");
-        return(NIL);
-    }
-    sieve_current_record(sieve, sieve_text);
-    sieve_live_record(sieve, sieve_text);
-
-    if (sieve_text && sieve_text[0] && !checksum_test(sieve_text, pool)) {
-        account_message(account, "Manually maintained Sieve file");
-        return(NIL);
-    }
-
     string_strdup(&account->vacation_msg, vacation_msg);
     string_strdup(&account->vacation_aliases, vacation_aliases);
+    string_strdup(&account->vacation_subject, vacation_subject);
     string_strdup(&account->spam_whitelist, spam_whitelist);
 
     if (!account_support_process_filter(account, filters, pool))
@@ -696,6 +712,11 @@ account_sieve_mail_update(struct account *account, struct pool *pool)
         account_sieve_stuff_string(b, aliases);
     }
 
+    if (account->vacation_subject && account->vacation_subject[0]) {
+        bputs(b, "vacation_subject:"CRLF);
+        account_sieve_stuff_string(b, account->vacation_subject);
+    }
+
     if (account->vacation_msg && account->vacation_msg[0]) {
         bputs(b, "vacation_msg:"CRLF);
         account_sieve_stuff_string(b, account->vacation_msg);
