@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/draft.c,v 1.17 2009/06/30 08:22:32 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/draft.c,v 1.20 2010/07/02 16:15:57 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -915,26 +915,30 @@ draft_make_single_address(struct session *session,
     struct request *request = session->request;
     struct pool *pool = request->pool;
     char *s;
-    unsigned long count;
     unsigned long len = 0;
 
     if (personal && personal[0]) {
-        if (string_atom_has_special(personal))
-            personal =
-                pool_printf(pool, "\"%s\"",
-                            string_atom_quote(pool, personal));
+        unsigned long count = 0;
 
-        for (s = personal, count = 0, len = 0; *s; s++) {
+        for (s = personal; *s; s++) {
             if ((*s) & 0x80)
                 count++;
         }
 
         if (count > 0) {
             len = draft_rfc1522_encode(mb, personal);
+        } else if (string_atom_has_special(personal)) {
+            personal =
+                pool_printf(pool, "\"%s\"",
+                            string_atom_quote(pool, personal));
+            
+            bputs(mb, personal);
+            len = strlen(personal);
         } else {
             bputs(mb, personal);
             len = strlen(personal);
         }
+
         if (mailbox && mailbox[0] && host && host[0]) {
             bprintf(mb, " <%s@%s>", mailbox, host);
             len += 4 + strlen(mailbox) + strlen(host);
@@ -1814,7 +1818,7 @@ draft_restore_postponed(struct draft *d,
 
         if (a->personal) {
             char *s = pool_strdup(d->pool, a->personal);
-            void *t = pool_alloc(pool, strlen(s));
+            void *t = pool_alloc(d->pool, strlen(s));
 
             d->from_personal
                 = (char *) rfc1522_decode(t, strlen(s), s, NIL);
@@ -1960,6 +1964,15 @@ draft_restore_postponed(struct draft *d,
 
         if (decode_msg != init_msg)
             fs_give((void **) &decode_msg);
+
+        /* Slightly unpleasant hack to remove final CRLF from message
+           if it had two. ml_fetchbody() should always use CRLF */
+        len = strlen(d->body);
+
+        while ((len > 4) && !strcmp(d->body+len-4, "\015\012\015\012")) {
+            d->body[len-2] = '\0';
+            len -= 2;
+        }
     } else
         d->body = pool_strdup(d->pool,
                               "(Message body was not text: suppressed)"
